NodeHost

Struct NodeHost 

pub struct NodeHost { /* private fields */ }
Concrete Node-compatible capability state.

Environment and arguments are explicit rather than inherited from the embedding process, keeping executions independent of the invoking machine.

Implementations

Source

impl NodeHost

pub fn new() -> Self

pub fn stdout(&self) -> &[u8]

pub fn stderr(&self) -> &[u8]

pub const fn exit_code(&self) -> i32

pub fn set_argv(&mut self, argv: impl IntoIterator<Item = String>)

pub fn argv(&self) -> &[String]

pub fn env(&self, name: &str) -> Option<&str>

pub fn set_env(&mut self, name: impl Into<String>, value: impl Into<String>)

pub fn delete_env(&mut self, name: &str) -> bool

pub fn set_script_compiler(&mut self, compiler: Box<dyn CompileProvider>)